==> gparted-0.2.5.tar.bz2: gparted-0.2.5/include/xfs.h <==
/* Copyright (C) 2004 Bart
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 
#ifndef DEFINE_XFS
#define DEFINE_XFS

#include "../include/FileSystem.h"

namespace GParted
{

class xfs : public FileSystem
{
public:
	FS get_filesystem_support() ;
	void Set_Used_Sectors( Partition & partition ) ;
	bool Create( const Partition & new_partition, std::vector<OperationDetails> & operation_details ) ;
	bool Resize( const Partition & partition_new, 
		     std::vector<OperationDetails> & operation_details,
		     bool fill_partition = false ) ;
	bool Copy( const Glib::ustring & src_part_path,
		   const Glib::ustring & dest_part_path,
		   std::vector<OperationDetails> & operation_details ) ;
	bool Check_Repair( const Partition & partition, std::vector<OperationDetails> & operation_details ) ;
};

} //GParted

#endif //XFS

==> gparted-0.4.7.tar.bz2: gparted-0.4.7/include/xfs.h <==
/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 
#ifndef DEFINE_XFS
#define DEFINE_XFS

#include "../include/FileSystem.h"

namespace GParted
{

class xfs : public FileSystem
{
public:
	FS get_filesystem_support() ;
	void set_used_sectors( Partition & partition ) ;
	void read_label( Partition & partition ) ;
	bool write_label( const Partition & partition, OperationDetail & operationdetail ) ;
	bool create( const Partition & new_partition, OperationDetail & operationdetail ) ;
	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition = false ) ;
	bool copy( const Glib::ustring & src_part_path,
		   const Glib::ustring & dest_part_path,
		   OperationDetail & operationdetail ) ;
	bool check_repair( const Partition & partition, OperationDetail & operationdetail ) ;
};

} //GParted

#endif //XFS
